==> 37sy-build-1.2.8.tgz: package/bin/index.js <==
#!/usr/bin/env node
var commander = require("commander");
var pkg = require('../package.json');
var fs = require("fs");

var config = require("../config.json")

var pojectPath = process.cwd()+"/build.json";
var Client = require('ftp');
var ftp = new Client();

var buildJson = require("./buildJson.js")

global.setting = {};


//更换临时目录

if(config.__tempDir){
	global.__tempDir = config.__tempDir+"/"+pkg.name;
}else{
	global.__tempDir = (process.env.APPDATA || (process.platform == 'darwin' ? process.env.HOME + 'Library/Preferences' : '/var/local'))+"/"+pkg.name;
}
global.__git = config.__git;

var base = require("./base.js");

commander
.version(pkg.version)
.option("-i,--init","生成模板目录")
.option("-u,--update","升级模板文件")
commander.parse(process.argv);

if(!commander.update){
	if(!base.checkInit()){
		console.error("运行fe set fecache xx 初始化临时目录");
		console.error("运行fe -u 更新配置");
		process.exit();
	}else{
		
		base.init();
	}
}else{
	base.hotUpdate();
}

if(commander.init){
	cnnectFtp(base.getFtp().product,function(){
		buildJson.start(ftp);
	})
}

commander
  .command('dev')
  .description('测试环境')
  .option("-l, --live", "开启实时同步")
  .action(function(options){
  	if(options.live){
  		setting.live = true;
  	}
    setting.env = "dev";
	startGulp()

  });
commander
	.command('pro')
	.description('生产环境')
	.option("-l, --live", "开启实时同步")
	.action(function(options){
		if(options.live){
			setting.live = true;
		}
		setting.env = "pro";
		startGulp()
	});
commander
	.command('test')
	.description('mocha测试')
	.option("-l, --live", "开启实时同步")
	.action(function(options){
		if(options.live){
			setting.live = true;
		}
		setting.env = "test";
		startGulp()
	});
commander
	.command('set <name> [content]')
	.description('配置')
	
	.action(function(name,content){
		 if(name != "" && typeof content!="undefined"){
		 	updateSetting(name,content);
		 }
	});
commander.parse(process.argv);



function startGulp(){
	//检测是否存在配置文件
	if(!fs.existsSync(pojectPath)){
		console.error("缺少配置文件");
		process.exit();
	}
	const gulp = require("../lib/logEventsGulp.js");
	if(setting.env == 'test'){
		require("../gulp/test.js");
		gulp.start("default");
		return;
	}
    var pjConfig = require(pojectPath);

	setting.src= pjConfig.src||".";
	setting.dist= pjConfig.dist||(__tempDir+"/dist");
	setting.cache = __tempDir+"/_cache";
	setting.specify = pjConfig.specify;
	setting.res = pjConfig.res||pjConfig.cdn_path;
	setting.html = pjConfig.html||pjConfig.htmlPath;;
	setting.cdn_path ="http://"+ setting.res;

	
	if(setting.env=="pro"){
		setting.ftp=base.getFtp().product;
	}else if(setting.env=="dev"){
		setting.ftp=base.getFtp().test;
	}else{
		setting.env = "local";
		setting.ftp="";
	}
	
	const cwdGulpfilePath = process.cwd() + '/build.js';

	if (fs.existsSync(cwdGulpfilePath)){
	    require(cwdGulpfilePath);
	}

	require("../gulp/build.js");

	gulp.start("default");
}


if(process.argv[2]==undefined){
	startGulp();
}

function updateSetting(name,val){
	var settingPath = path.resolve("../config.json");
	if(typeof setting[name] == "undefined"){
		return;
	}
	setting[name] = val;
	fs.writeFileSync(settingPath,JSON.stringify(setting,null,1));
}

function cnnectFtp(obj,callback){
	if(!ftp.connected){
		ftp.connect(obj);
		ftp.on("ready",function(){
			callback&&callback(ftp)
		})
	}
}



//组装gulpfile

//运行gulp命令

==> 37sy-build-1.3.1.tgz: package/bin/index.js <==
#!/usr/bin/env node
'use strict';
var commander = require("commander");
var pkg = require('../package.json');
var fs = require("fs");

var config = require("../config.json")

var pojectPath = process.cwd()+"/build.json";
var Client = require('ftp');
var ftp = new Client();

var buildJson = require("./buildJson.js")

global.setting = {};


//更换临时目录

if(config.__tempDir){
	global.__tempDir = config.__tempDir+"/"+pkg.name;
}else{
	global.__tempDir = (process.env.APPDATA || (process.platform == 'darwin' ? process.env.HOME + 'Library/Preferences' : '/var/local'))+"/"+pkg.name;
}
global.__git = config.__git;

var base = require("./base.js");

commander
.version(pkg.version)
.option("-i,--init","生成模板目录")
.option("-u,--update","升级模板文件");
commander
  .command("build")
  .description('本地构建')
  .action(function(options){
  	setting.env = "build";
	startGulp()
  });
commander.parse(process.argv);

if(!commander.update){
	if(!base.checkInit()){
		console.error("运行fe set fecache xx 初始化临时目录");
		console.error("运行fe -u 更新配置");
		process.exit();
	}else{
		
		base.init();
	}
}else{
	base.hotUpdate();
}

if(commander.init){
	cnnectFtp(base.getFtp().product,function(){
		buildJson.start(ftp);
	})
}

commander
  .command('dev')
  .description('测试环境')
  .option("-l, --live", "开启实时同步")
  .action(function(options){
  	if(options.live){
  		setting.live = true;
  	}
    setting.env = "dev";
	startGulp()

  });
commander
	.command('pro')
	.description('生产环境')
	.option("-l, --live", "开启实时同步")
	.action(function(options){
		if(options.live){
			setting.live = true;
		}
		setting.env = "pro";
		startGulp()  
	});
commander
	.command('test')
	.description('mocha测试')
	.option("-l, --live", "开启实时同步")
	.action(function(options){
		if(options.live){
			setting.live = true;
		}
		setting.env = "test";
		startGulp()
	});
commander
	.command('set <name> [content]')
	.description('配置')
	
	.action(function(name,content){
		 if(name != "" && typeof content!="undefined"){
		 	updateSetting(name,content);
		 }
	});
commander.parse(process.argv);



function startGulp(){
	//检测是否存在配置文件
	if(!fs.existsSync(pojectPath)){
		console.error("缺少配置文件");
		process.exit();
	}
	const gulp = require("../lib/logEventsGulp.js");
	if(setting.env == 'test'){
		require("../gulp/test.js");
		gulp.start("default");
		return;
	}

    var pjConfig = require(pojectPath);
    if(setting.env == 'build'){
    	pjConfig.dist="./dist";
    }
	setting.src= pjConfig.src||".";
	setting.dist= pjConfig.dist||(__tempDir+"/dist");
	setting.cache = __tempDir+"/_cache";
	setting.specify = pjConfig.specify;
	setting.res = pjConfig.res||pjConfig.cdn_path;
	setting.html = pjConfig.html||pjConfig.htmlPath;;
	setting.cdn_path ="http://"+ setting.res;
	
	if(setting.env=="pro"){
		setting.ftp=base.getFtp().product;
	}else if(setting.env=="dev"){
		setting.ftp=base.getFtp().test;
	}else if(setting.env == "build"){
		setting.ftp={};
	}else{
		setting.env = "local";
		setting.ftp={};
	}
	
	const cwdGulpfilePath = process.cwd() + '/build.js';

	if (fs.existsSync(cwdGulpfilePath)){
	    require(cwdGulpfilePath);
	}

	require("../gulp/build.js");

	gulp.start("default");
}


if(process.argv[2]==undefined){
	startGulp();
}

function updateSetting(name,val){
	var settingPath = path.resolve("../config.json");
	if(typeof setting[name] == "undefined"){
		return;
	}
	setting[name] = val;
	fs.writeFileSync(settingPath,JSON.stringify(setting,null,1));
}

function cnnectFtp(obj,callback){
	if(!ftp.connected){
		ftp.connect(obj);
		ftp.on("ready",function(){
			callback&&callback(ftp)
		})
	}
}



//组装gulpfile

//运行gulp命令
